from django.db import models

class Unit (models.Model):
    name = models.CharField (max_length = 200, unique = True)
    symbol = models.CharField (max_length = 10)

    def __unicode__ (self):
        return self.name

class Nutritient (models.Model):
    name = models.CharField (max_length = 200, unique = True)
    unit = models.ForeignKey (Unit)
    sortOrder = models.SmallIntegerField ()

    def __unicode__ (self):
        return self.name

class Meal (models.Model):
    name = models.CharField (max_length = 200, unique = True)
    nutrient = models.ManyToManyField (Nutritient, through = "MealNutritient")

    def __unicode__ (self):
        return self.name

class MealNutritient (models.Model):
    meal = models.ForeignKey (Meal)
    nutritient = models.ForeignKey (Nutritient)
    value = models.DecimalField (max_digits = 10, decimal_places = 2)

    def __unicode__ (self):
        return unicode (self.meal) + ' ' + unicode (self.nutritient)

class MenuType (models.Model):
    constant = models.CharField (max_length = 100, primary_key = True)
    name = models.CharField (max_length = 200, unique = True)

    def __unicode__ (self):
        return self.name

class Menu (models.Model):
    day = models.DateField ()
    type = models.ForeignKey (MenuType, unique_for_date = "day")
    meals = models.ManyToManyField (Meal, through = "MenuMeal")

    def __unicode__ (self):
        return unicode (self.day) + ' ' + unicode (self.type)

class MenuMealType (models.Model):
    constant = models.CharField (max_length = 100, primary_key = True)
    name = models.CharField (max_length = 200, unique = True)
    sortOrder = models.SmallIntegerField ()

    def __unicode__ (self):
        return self.name

class MenuMeal (models.Model):
    menu = models.ForeignKey (Menu)
    meal = models.ForeignKey (Meal)
    type = models.ForeignKey (MenuMealType)

    def __unicode__ (self):
        return unicode (self.menu) + ' ' + unicode (self.meal)
